@@ -4,13 +4,16 @@
 # if you have many models here with many references from one model to another this may
 # raise a RecursionError
 # to avoid this, import only the models that you directly need like:
-# from from basistheory.model.pet import Pet
+# from basistheory.model.pet import Pet
 # or import this package, but before doing it, use:
 # import sys
 # sys.setrecursionlimit(n)
 
+from basistheory.model.access_rule import AccessRule
 from basistheory.model.application import Application
 from basistheory.model.application_paginated_list import ApplicationPaginatedList
+from basistheory.model.application_template import ApplicationTemplate
+from basistheory.model.condition import Condition
 from basistheory.model.create_application_request import CreateApplicationRequest
 from basistheory.model.create_proxy_request import CreateProxyRequest
 from basistheory.model.create_reactor_formula_request import CreateReactorFormulaRequest
@@ -32,6 +35,7 @@ from basistheory.model.get_tokens import GetTokens
 from basistheory.model.log import Log
 from basistheory.model.log_entity_type import LogEntityType
 from basistheory.model.log_paginated_list import LogPaginatedList
+from basistheory.model.monthly_active_token_history import MonthlyActiveTokenHistory
 from basistheory.model.pagination import Pagination
 from basistheory.model.permission import Permission
 from basistheory.model.privacy import Privacy
